summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authordaniel oeh <daniel.oeh@gmail.com>2012-09-02 18:01:15 +0200
committerdaniel oeh <daniel.oeh@gmail.com>2012-09-02 18:01:15 +0200
commitb1c862142f60e88c63f5fedb2d220f1ca8cc8eae (patch)
treeb5f0ffcb8d2d3dace38c963752313600384d7970
parent0f6e78da25d42932bfcd2b8ce75a5715f2f1251b (diff)
downloadAntennaPod-b1c862142f60e88c63f5fedb2d220f1ca8cc8eae.zip
Exclude failed image downloads from download report
-rw-r--r--src/de/danoeh/antennapod/service/download/DownloadService.java8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/de/danoeh/antennapod/service/download/DownloadService.java b/src/de/danoeh/antennapod/service/download/DownloadService.java
index 0d7b97f96..04a628d23 100644
--- a/src/de/danoeh/antennapod/service/download/DownloadService.java
+++ b/src/de/danoeh/antennapod/service/download/DownloadService.java
@@ -411,8 +411,8 @@ public class DownloadService extends Service {
* Creates a notification at the end of the service lifecycle to notify the
* user about the number of completed downloads. A report will only be
* created if the number of successfully downloaded feeds is bigger than 1
* or if there is at least one failed download or if there is at least
* one downloaded media file.
*/
private void updateReport() {
// check if report should be created
@@ -430,7 +430,9 @@ public class DownloadService extends Service {
}
successfulDownloads++;
} else {
- createReport = true;
+ if (status.getFeedFile().getClass() != FeedImage.class) {
+ createReport = true;
+ }
failedDownloads++;
}
}
@@ -411,8 +411,8 @@ public class DownloadService extends Service {
* user about the number of completed downloads. A report will only be
* created if the number of successfully downloaded feeds is bigger than 1
- * or if there is at least one failed download or if there is at least
- * one downloaded media file.
+ * or if there is at least one failed download which is not an image or if
+ * there is at least one downloaded media file.
*/
private void updateReport() {